#
# spec file for package python-pytest-mpi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?sle_version} && 0%{?sle_version} < 150300
  %define mpiver openmpi
%else
  %define mpiver openmpi4
%endif

%define modname pytest_mpi
Name:           python-pytest-mpi
Version:        0.6
Release:        4.2.2.1.sr20250302
Summary:        MPI plugin for pytest
License:        BSD-3-Clause
URL:            https://pytest-mpi.readthedocs.io
Source:         https://files.pythonhosted.org/packages/source/p/pytest-mpi/pytest-mpi-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest
Recommends:     python-mpi4py
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  openmpi-macros-devel
BuildRequires:  %{mpiver}
BuildRequires:  %{python_module mpi4py}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sybil >= 3}
# /SECTION
%python_subpackages

%description
mpi plugin for pytest to collect information from openmpi-based tests.

%prep
%autosetup -p1 -n pytest-mpi-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Exclude test_fixtures, it fails for i586 arch with Segmentation fault
donttest="test_fixtures"
%if "%{_arch}" == "s390x"
# Exclude some test_mpi_ that fails for s390x arch with Segmentation fault
donttest+=" or test_mpi_with_mpi or test_mpi_only_mpi or test_mpi_skip_under_mpi or test_mpi_xfail or test_mpi_xfail_under_mpi"
%endif
%setup_openmpi
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_DEBUG_TEMPROOT=$(mktemp -d -p ./ py%{$python_version_nodots}.XXX)
$python -m pytest -v -p pytester --runpytest=subprocess -k "not ($donttest)"
rm -fr ${PYTEST_DEBUG_TEMPROOT}
}

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}*.*-info/

%changelog
* Tue Mar  4 2025 Atri Bhattacharya <badshah400@gmail.com>
- Fix test runs in %%check.
- Switch to %%pyproject_* macros for build.
- Drop no longer necessary skip_python* macro definitions.
* Tue Feb 25 2025 Daniel Garcia <daniel.garcia@suse.com>
- Fix openmpi paths in %%check section
* Tue May 28 2024 Daniel Garcia <daniel.garcia@suse.com>
- Skip some tests that produces a Segmentation fault in s390x
* Thu Nov 10 2022 Daniel Garcia <daniel.garcia@suse.com>
- Disable again test_fixtures that produces a Segmentation fault in i586
* Tue Nov  8 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove pml/ob1 option for tests, bsc#1205139
* Tue Nov  8 2022 Daniel Garcia <daniel.garcia@suse.com>
- Disable test_fixtures that produces a Segmentation fault in i586
* Tue Nov  8 2022 Daniel Garcia <daniel.garcia@suse.com>
- Use pml ob1 to run tests
* Tue Nov  8 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove pytest-mpi-pr37-sybil3.patch, not needed anymore
- Update to 0.6:
  * Again no codebase changes, testing/CI and packaging fixes only.
  * Update Azure Pipelines to use latest images (so CI runs again)
  * Update versioneer to work on future Python versions.
  * Fix doctests infrastructure
* Mon Dec 27 2021 Ben Greiner <code@bnavigator.de>
- add pytest-mpi-pr37-sybil3.patch -- gh#aragilar/pytest-mpi#37
* Sun Sep 26 2021 Hans-Peter Jansen <hpj@urpla.net>
- Fix build for SLES/Leaps
* Sun Sep 26 2021 Hans-Peter Jansen <hpj@urpla.net>
- Fix build for Tumbleweed
* Mon Mar 15 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.5
  * fixes the test suite for pytest 6.2
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29). Mpi4py depends on NumPy,
  pytest-mpi us almost useless (and not testable) without mpi4py.
* Tue Feb 23 2021 Ben Greiner <code@bnavigator.de>
- Disable most of the test suite. The offending code not working
  with pytest 6.2 is in the test suite, not the plugin code itself
  gh#aragilar/pytest-mpi#17
* Fri Dec  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
